diff --git a/tests/components/emulated_hue/test_hue_api.py b/tests/components/emulated_hue/test_hue_api.py
index 349d53aaee5..0ddc429b2d9 100644
--- a/tests/components/emulated_hue/test_hue_api.py
+++ b/tests/components/emulated_hue/test_hue_api.py
@@ -238,7 +238,7 @@ async def test_light_without_brightness_supported(hass_hue, hue_client):
     )
 
     assert light_without_brightness_json["state"][HUE_API_STATE_ON] is True
-    assert light_without_brightness_json["type"] == "On/off light"
+    assert light_without_brightness_json["type"] == "On/off plug-in unit"
 
 
 async def test_light_without_brightness_can_be_turned_off(hass_hue, hue_client):
diff --git a/homeassistant/components/emulated_hue/hue_api.py b/homeassistant/components/emulated_hue/hue_api.py
index 459a13c066c..118bf7e3eaa 100644
--- a/homeassistant/components/emulated_hue/hue_api.py
+++ b/homeassistant/components/emulated_hue/hue_api.py
@@ -704,9 +704,10 @@ def entity_to_json(config, entity):
         retval["modelid"] = "HASS123"
         retval["state"].update({HUE_API_STATE_BRI: state[STATE_BRIGHTNESS]})
     else:
-        # On/off light (Zigbee Device ID: 0x0000)
-        # Supports groups, scenes and on/off control
-        retval["type"] = "On/off light"
+        # On/off plug-in unit (Zigbee Device ID: 0x0000)
+        # Supports groups and on/off control
+        # Used for compatibility purposes with Alexa instead of "On/off light"
+        retval["type"] = "On/off plug-in unit"
         retval["modelid"] = "HASS321"
 
     return retval